pub struct DirtyAuxInfo<L: SecurityLevel = SecurityLevel128> {
pub p: Integer,
pub q: Integer,
pub N: Vec<Integer>,
pub pedersen_params: Vec<PedersenParams>,
pub security_level: PhantomData<L>,
}Expand description
Dirty aux info
Fields
p: IntegerSecret prime $p$
q: IntegerSecret prime $q$
N: Vec<Integer>Paillier public keys $\vec N = (N_j)_{j \in [n]}$
pedersen_params: Vec<PedersenParams>Parties Pedersen parameters
pedersen_params[i] corresponds to pedersen params of $\ith$ party
Note that although this is supposed to only contain public information, when CRT optimization is enabled, it may contain sensitive information!
security_level: PhantomData<L>Security level that was used to generate aux info
Implementations
Sourceimpl<L: SecurityLevel> DirtyAuxInfo<L>
impl<L: SecurityLevel> DirtyAuxInfo<L>
Sourcepub fn precompute_multiexp_tables(&mut self) -> Result<(), InvalidKeyShare>
pub fn precompute_multiexp_tables(&mut self) -> Result<(), InvalidKeyShare>
Precomputes multiexponentiation tables
Enables optimization that makes signing and presigning faster. Precomputation may take a while. It noticebly increases size of aux data both in RAM and on disk (after serialization).
Returns error if building a multiexp table failed. In this case, the key share stays unmodified. On success, multiexp tables are saved into the key share (old tables, if present, are overwritten).
Sourcepub fn multiexp_tables_size(&self) -> usize
pub fn multiexp_tables_size(&self) -> usize
Returns size of all multiexp tables (in bytes) stored within key share
Sourcepub fn precompute_crt(&mut self, i: u16) -> Result<(), InvalidKeyShare>
pub fn precompute_crt(&mut self, i: u16) -> Result<(), InvalidKeyShare>
Precomputes CRT parameters
Refer to PedersenParams::precompute_crt for the docs.