PedersenParams

Struct PedersenParams 

pub struct PedersenParams {
    pub hat_N: Integer,
    pub s: Integer,
    pub t: Integer,
    pub multiexp: Option<Arc<MultiexpTable>>,
    pub crt: Option<CrtExp>,
}
Party pedersen parameters

Fields

hat_N: Integer

Defines Pedersen Ring modulo $\hat N_i$

s: Integer

Ring-Perdesten parameter $s_i$

t: Integer

Ring-Perdesten parameter $t_i$

multiexp: Option<Arc<MultiexpTable>>

Precomputed table for faster multiexponentiation

It’s used to compute $s_i^x t_i^y \bmod \hat N_i$ faster given $x,y$ in certain range predefined by security level

crt: Option<CrtExp>

Enables faster modular exponentiation when factorization of N is known

Note that it is extreamly sensitive! Leaking crt exposes Paillier private key.

It’s used to compute $x^y \bmod \hat N_i$ faster

Implementations

Source

impl PedersenParams

pub fn precompute_multiexp_table<L: SecurityLevel>( &mut self, ) -> Result<(), InvalidKeyShare>

Precompute multiexponentiation table

Enables optimization that makes signing and presigning faster. Precomputation may take a while. It noticebly increases size of aux data both in RAM and on disk (after serialization).

Returns error if building a multiexp table failed. On success, multiexp tables are saved (old tables, if present, are overwritten).

Note that provided security level must match the actual security level being used in the protocol. Otherwise, optimization won’t work, and it actually will make the protocol slower.

pub fn precompute_crt( &mut self, p: &Integer, q: &Integer, ) -> Result<(), InvalidKeyShare>

Precomputes CRT parameters

Enables optimization of modular exponentiation in Zero-Knowledge proofs validation. Precomputation should be relatively fast. It increases size of key share in RAM and on disk, but not noticeably.

Takes primes p, q as input that correspond to signer Paillier secret key.

Returns error if provided primes do not correspond to a Paillier secret key of the signer, or if precomputation failed. On success, updates CRT params stored within the structure (old params, if present, are overwritten)

Note: CRT parameters contain secret information. Leaking them exposes secret Paillier key. Keep them secret (as well as rest of the key share).