ValidateError

Struct ValidateError 

pub struct ValidateError<T, E> { /* private fields */ }
Validation error

Contains an error that explains why value was considered invalid, and the value itself. It can be used to reclaim ownership over invalid value.

Implementations

Source

impl<T, E> ValidateError<T, E>

pub fn invalid_value(&self) -> &T

Returns reference to value that did not pass validation

pub fn error(&self) -> &E

Returns error explaining why value was considered invalid

pub fn into_invalid_value(self) -> T

Reclaim ownership over invalidated value

pub fn into_error(self) -> E

Returns ownership over error