AnyKeyShare

Trait AnyKeyShare 

pub trait AnyKeyShare<E: Curve>: AsRef<IncompleteKeyShare<E>> {
    // Provided methods
    fn n(&self) -> u16 { ... }
    fn min_signers(&self) -> u16 { ... }
    fn shared_public_key(&self) -> NonZero<Point<E>> { ... }
}
Any (validated) key share

Implemented for both KeyShare and IncompleteKeyShare. Used in methods that accept both types of key shares, like reconstruct_secret_key.

Provided Methods

fn n(&self) -> u16

Returns amount of key co-holders

fn min_signers(&self) -> u16

Returns threshold

Threshold is an amount of signers required to cooperate in order to sign a message and/or generate presignature

fn shared_public_key(&self) -> NonZero<Point<E>>

Returns public key shared by signers

Implementors