pub struct DirtyKeyShare<E: Curve, L: SecurityLevel = SecurityLevel128> {
pub core: DirtyIncompleteKeyShare<E>,
pub aux: DirtyAuxInfo<L>,
}Expand description
Dirty (unvalidated) key share
Key share is obtained as output of key refresh protocol. It contains a core share and auxiliary data required to carry out signing.
Compared to the paper, we removed the El-Gamal private key as it’s not used for 3-round presigning, which is the only one we provide
Fields
core: DirtyIncompleteKeyShare<E>Core key share
aux: DirtyAuxInfo<L>Auxiliary info
Implementations
Sourcepub fn precompute_crt(&mut self) -> Result<(), InvalidKeyShare>
pub fn precompute_crt(&mut self) -> Result<(), InvalidKeyShare>
Precomputes CRT parameters
Enables optimization of modular exponentiation in Zero-Knowledge proofs validation. Precomputation should be relatively fast. It increases size of key share in RAM and on disk, but not noticeably.
Returns error if precomputation failed. In this case, the key share stays unmodified. On success, CRT parameters are saved into the key share (old params, if present, are overwritten)
Note: CRT parameters contain secret information. Leaking them exposes secret Paillier key. Keep them secret (as well as rest of the key share).
Methods from Deref<Target = DirtyIncompleteKeyShare<E>>
Methods from Deref<Target = DirtyKeyInfo<E>>
Returns share preimage associated with j-th signer
- For additive shares, share preimage is defined as
j+1 - For VSS-shares, share preimage is scalar $I_j$ such that $x_j = F(I_j)$ where $F(x)$ is polynomial co-shared by the signers and $x_j$ is secret share of j-th signer
Note: if you have no idea what it is, probably you don’t need it.
Sourcepub fn is_hd_wallet(&self) -> bool
Available on crate feature hd-wallet only.
pub fn is_hd_wallet(&self) -> bool
hd-wallet only.Checks whether the key is HD-capable
Sourcepub fn extended_public_key(&self) -> Option<ExtendedPublicKey<E>>
Available on crate feature hd-wallet only.
pub fn extended_public_key(&self) -> Option<ExtendedPublicKey<E>>
hd-wallet only.Returns extended public key, if HD support was enabled
Sourcepub fn derive_child_public_key<Hd, ChildIndex>(
&self,
derivation_path: impl IntoIterator<Item = ChildIndex>,
) -> Result<ExtendedPublicKey<E>, HdError<<ChildIndex as TryInto<NonHardenedIndex>>::Error>>where
Hd: HdWallet<E>,
NonHardenedIndex: TryFrom<ChildIndex>,
Available on crate feature hd-wallet only.
pub fn derive_child_public_key<Hd, ChildIndex>(
&self,
derivation_path: impl IntoIterator<Item = ChildIndex>,
) -> Result<ExtendedPublicKey<E>, HdError<<ChildIndex as TryInto<NonHardenedIndex>>::Error>>where
Hd: HdWallet<E>,
NonHardenedIndex: TryFrom<ChildIndex>,
hd-wallet only.Derives child public key, if it’s HD key, using HdWallet algorithm