pub type KeyShare<E, L = SecurityLevel128> = Valid<DirtyKeyShare<E, L>>;Expand description
Key share
Key share is obtained as output of key refresh protocol. It contains a core share and auxiliary data required to carry out signing.
Compared to the paper, we removed the El-Gamal private key as it’s not used for 3-round presigning, which is the only one we provide
Correctness
This key share was checked to be valid and consistent. In order to
keep it valid and consistent, only immutable access to its fields is
provided. In case mutable access is needed, it can be converted into
dirty key share using .into_inner() method.
CRT and multiexponent optimizations
CRT parameters and multiexponentiation tables are not checked for correctness as there’s no simple and/or efficient way to do so. If you have chosen to benefit from those optimizations, be aware that invalid/inconsistent data may lead to unexpected and unverbose protocol termination and as well to security breach.
Aliased Type
pub struct KeyShare<E, L = SecurityLevel128>(/* private fields */);